package fxPuntti;

import java.io.PrintStream;
import java.net.URL;
import java.util.ResourceBundle;

import fi.jyu.mit.fxgui.Dialogs;
import fi.jyu.mit.fxgui.ListChooser;
import fi.jyu.mit.fxgui.ModalController;
import fi.jyu.mit.fxgui.TextAreaOutputStream;
import javafx.fxml.FXML;
import javafx.fxml.Initializable;
import javafx.scene.control.ScrollPane;
import javafx.scene.control.TextArea;
import javafx.scene.text.Font;
import puntti.Liike;
import puntti.Puntti;
import puntti.SailoException;


/**
 * Controlleri kutsuu luokkia ja siirtää ne käyttöliittymään
 * Kommunikoi käyttöliittymän ja koodin välillä
 * @author laspa
 * @version 20.1.2025
 *
 */
public class PunttiGUIController implements Initializable{
    
    @FXML private ListChooser<Liike> chooserLiikkeet;
    @FXML private ScrollPane panelLiike;


    
    @Override
    public void initialize(URL url, ResourceBundle bundle) {
        alusta();
    }
    
    @FXML void handleDefaultTallenna() {
        Dialogs.showMessageDialog("Ei osata vielä tallentaa");
    }
    

    @FXML void handleDefaultApua() {
        Dialogs.showMessageDialog("Ei osata vielä");
    }

    @FXML void handleDefaultMuokkaa() {
        Dialogs.showMessageDialog("Ei osata vielä");
    }

    @FXML void handleDefaultPoistaTulos() {
        Dialogs.showMessageDialog("Ei osata poistaa tulosta");
    }

    @FXML void handleDefaultTiedosto() {
        Dialogs.showMessageDialog("Ei osata vielä");
    }

    @FXML void handleDefaultUusiLiike() {
        //ModalController.showModal(PunttiGUIController.class.getResource("LisaaUusiLiikeGUIView.fxml"), "Liike", null, "");
        uusiLiike();
    }

    @FXML private void handleUusiTulos() {
        ModalController.showModal(PunttiGUIController.class.getResource("LisaaUusiTulosGUIView.fxml"), "Tulos", null, "");
    }

    //___________________________________________________________________ ALLE JAVA
    
    
    
    
    /**
     * puntti mitä käytetään
     */
    private Puntti puntti;
    private TextArea areaLiike = new TextArea(); //Poista lopuksi
    
    
    private void alusta() {
        chooserLiikkeet.clear();
        chooserLiikkeet.addSelectionListener(e -> naytaLiike());
        panelLiike.setContent(areaLiike);
        areaLiike.setFont(new Font("Arial", 12));
        panelLiike.setFitToHeight(true);
        
    }
    
    
    private void naytaLiike() {
        Liike liikeKohdalla = chooserLiikkeet.getSelectedObject();
        
        if (liikeKohdalla == null) return;
        
        areaLiike.setText("");
        try(PrintStream os = TextAreaOutputStream.getTextPrintStream(areaLiike)){
                liikeKohdalla.tulosta(os);
        }
    }
    
    private void lueTiedosto(@SuppressWarnings("unused") String nimi) {
//        punttinimi = nimi;
//        setTitle("Puntti - " + nimi);
        String virhe = "Ei ostata lukea vielä";
//        if (virhe != null)
            Dialogs.showMessageDialog(virhe);
    }
    
    /**
     * @return palauttaa true jos avataan ja false jos ei avata
     */
    public boolean avaa() {
        String uusinimi = KirjautumissivuGUIController.kysyNimi(null, "Vili");
        if (uusinimi == null) return false;
        lueTiedosto(uusinimi);
        return true;
    }
      


    /**
     * Asetetaan käytettävä puntti
     * @param puntti jota käytetään
     */
    public void setPuntti(Puntti puntti) {
        this.puntti = puntti;
        
    }
    
    
    private void hae(int lid) {
        chooserLiikkeet.clear();
        
        int index = 0;
        for (int i=0; i < puntti.getLiikkeita(); i++) {
            Liike liike = puntti.annaLiike(i);
            if(liike.getLid() == lid) index = i;
            chooserLiikkeet.add(""+liike.getNimi(), liike);
        }
        chooserLiikkeet.setSelectedIndex(index);
        
    }
    
    
    /**
     * Lisätään Punttiin uusi liike
     */
    private void uusiLiike() {
        Liike uusi = new Liike();
        uusi.lisaaLiike();
        uusi.taytaKyykky();
        try {
            puntti.lisaa(uusi);
        } catch (SailoException e) {
            Dialogs.showMessageDialog("Ounou ongelma lisätessä liikettä" + e.getMessage());
        }
        hae(uusi.getLid());
    }
    
   

}